@@ -683,7 +683,16 @@ def run_server(port, key, bindaddr=None, allow=(),
         addrs = socket.getaddrinfo(bindaddr, port, gai_family)
         family, socktype, proto, canonname, sockaddr = addrs[0]
 
-    sock = socket.socket(family, socket.SOCK_STREAM)
+    try:
+        sock = socket.socket(family, socket.SOCK_STREAM)
+    except socket.error as e:
+        # "An address incompatible with the requested protocol was used"
+        # - means IPv6 is not supported
+        if x.args == 10047:
+            family = socket.AF_INET
+            sock = socket.socket(family, socket.SOCK_STREAM)
+        else:
+            raise
 
     if family == socket.AF_INET6 and socket.has_ipv6:
         # Windows needs this socket option set to listen on both IPV4 and
@@ -698,6 +707,7 @@ def run_server(port, key, bindaddr=None, allow=(),
 
     sock.bind(sockaddr)
     sock.listen(1)
+
     _server_socket = sock
 
     print('Listening on port %d' % port)
